Rx<T> class

Implementers

Constructors

Rx(T seed)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<T>
no setter
value ↔ T
getter/setter pair

Methods

close() Future<void>
emit(T value) → void
The same like setting 'value'
listen(void onData(T), {Function? onError, void onDone()?, bool? cancelOnError}) StreamSubscription<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
update() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited