RxList<T> class
Properties
- first → T
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- last → T
-
no setter
- length → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
List< T> > -
no setterinherited
-
value
↔ List<
T> -
getter/setter pairinherited
Methods
-
add(
T item) → void -
addAll(
Iterable< T> item) → void -
clear(
) → void -
close(
) → Future< void> -
inherited
-
emit(
List< T> value) → void -
The same like setting 'value'
inherited
-
fillRange(
int start, int end, [T? fillValue]) → void -
insert(
int index, T element) → void -
insertAll(
int index, Iterable< T> elements) → void -
listen(
void onData(List< T> ), {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription<List< T> > -
inherited
-
map<
Y> (Y toElement(T)) → Iterable< Y> -
mapToWidgets(
Widget toWidget(T)) → List< Widget> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
T? item) → void -
removeAt(
int index) → T -
removeLast(
) → T -
removeRange(
int start, int end) → void -
removeWhere(
bool test(T element)) → void -
replaceRange(
int start, int end, Iterable< T> replacements) → void -
retainWhere(
bool test(T element)) → void -
setAll(
int index, Iterable< T> elements) → void -
setRange(
int start, int end, Iterable< T> iterable, [int skipCount = 0]) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → T -
operator []=(
int index, T value) → void